##' Summary methods
##'
##' Display a summary of a fitted model object.
##'
##' @name summary
##' @rdname summary
##' @param object a fitted model object
##' @param \dots ignored
NULL

setGeneric("summary")
